import { CascadeType } from "../common/CascadeType";
import { StateMachineTransition } from "../common/StateMachineTransition";
import { DtoFieldMetadata } from "../dto/DtoMetadata";
import { ModelMetadata } from "./ModelMetadata";
export interface ModelFieldMetadata extends DtoFieldMetadata {
    /**
     * Whether this field is primary key.
     */
    pk?: {
        /**
         * Auto-incrementing PK, default to true if omitted.
         */
        isAutoIncrement?: boolean;
    };
    fk?: {
        /**
         * Id of the model to refer as foreign key.
         */
        relationDto?: ModelMetadata;
        /**
         * Whether to cascade on delete.
         */
        cascade?: CascadeType;
    };
    /**
     * Default value for the field if not provided
     */
    defaultValue?: any;
    /**
     * Store time of creation
     */
    creationTimestamp?: boolean;
    /**
     * Store time of last modification
     */
    modificationTimestamp?: boolean;
    index?: {
        groups?: string[];
    };
    unique?: {
        groupName?: string;
    };
    /**
     * State machine to validate for transition.
     */
    stateMachineTransition?: StateMachineTransition<any>[];
    /**
     * Allow regex search in this field and other fields that has searchable is true.
     */
    searchable?: {
        /**
         * Case sensitive for searching.
         */
        caseSensitive?: boolean;
        /**
         * Accent sensitive for searching.
         */
        accentSensitive?: boolean;
    };
    /**
     * Whether this field value graphically represents the record
     */
    isLabel?: boolean;
}
